@@ -28,12 +28,6 @@
 
 #include <gtk/gtk.h>
 
-#ifdef HAVE_CLUTTER
-#include <cogl/cogl.h>
-#include <clutter/clutter.h>
-#include <clutter-gtk/clutter-gtk.h>
-#endif
-
 #include "ar-debug.h"
 #include "ar-stock.h"
 #include "ar-runtime.h"
@@ -99,12 +93,6 @@ main_prog (void *closure, int argc, char *argv[])
 
   g_option_context_add_group (option_context, gtk_get_option_group (TRUE));
 
-#ifdef HAVE_CLUTTER
-  g_option_context_add_group (option_context, cogl_get_option_group ());
-  g_option_context_add_group (option_context, clutter_get_option_group_without_init ());
-  g_option_context_add_group (option_context, gtk_clutter_get_option_group ());
-#endif /* HAVE_CLUTTER */
-
   retval = g_option_context_parse (option_context, &argc, &argv, &error);
   g_option_context_free (option_context);
 
@@ -162,7 +150,7 @@ main (int argc, char *argv[])
   g_setenv ("GUILE_WARN_DEPRECATED", "detailed", TRUE);
   g_setenv ("GUILE_AUTO_COMPILE", "0", TRUE);
 
-  /* Set some env vars to disable ubuntu crap. They'll certainly patch this
+  /* Set some env vars to disable the ubuntu modules. They'll certainly patch this
    * out in their package, but anyone running from git will get the right
    * behaviour.
    */
